<?php

include_once ABSPATH . 'wp-admin/includes/plugin.php';

function dm_tva_shouldLoad()
{
    $dmActive = is_plugin_active('digimember/digimember.php');
    $tvaActive = is_plugin_active('thrive-apprentice/thrive-apprentice.php');

    return $dmActive && $tvaActive;
}

function dm_tva_requireBaseFiles()
{
    $paths = [
        path_join(WP_CONTENT_DIR, 'plugins/thrive-apprentice/inc/classes/integrations/class-tva-integration.php'),
        path_join(WP_CONTENT_DIR, 'plugins/thrive-apprentice/inc/classes/integrations/class-tva-integrations-manager.php'),
        path_join(WP_CONTENT_DIR, 'plugins/thrive-apprentice/inc/classes/integrations/class-tva-integration-item.php'),
    ];
    foreach ($paths as $path) {
        if (file_exists($path)) {
            require_once $path;
        }
    }
}

global $tva_integrations;

function dm_tva_replaceManager()
{
    global $tva_integrations;

    require_once path_join(__DIR__, 'classes/DM_Integrations_Manager.php');

    $tva_integrations = new DM_Integrations_Manager();
}

function dm_tva_upgrade_term_meta()
{
    global $wpdb;

    if (get_option('dm_tva_tmeta_upgrade')) {
        return;
    }

    $tbl = $wpdb->prefix . 'termmeta';
    $meta_key = 'tva_rules';
    $tmeta = $wpdb->get_results($wpdb->prepare('SELECT `term_id` FROM `' . $tbl . '` WHERE `meta_key` = %s', $meta_key), ARRAY_A);
    foreach ($tmeta as $m) {
        $term_id = $m['term_id'];
        $meta = get_term_meta($term_id, $meta_key, true);
        if (!is_array($meta)) {
            continue;
        }
        foreach ($meta as $ri => $rule) {
            if (!is_array($rule) || !isset($rule['integration']) || $rule['integration'] != 'digimember') {
                continue;
            }
            $items = isset($rule['items']) && is_array($rule['items']) ? $rule['items'] : [];
            foreach ($items as $ii => $item) {
                if (!is_numeric($item['id'])) {
                    $meta[$ri]['items'][$ii]['id'] = (int)str_replace('dm-', '', $item['id']);
                }
            }
        }
        update_term_meta($term_id, $meta_key, $meta);
    }
    update_option('dm_tva_tmeta_upgrade', true);
}

if (dm_tva_shouldLoad()) {
    dm_tva_requireBaseFiles();
    dm_tva_replaceManager();
    dm_tva_upgrade_term_meta();

    add_action('admin_enqueue_scripts', function () {
        wp_enqueue_style('dm_tva_style', plugin_dir_url(__FILE__) . 'assets/style.css');
    });
}